@@ -193,14 +193,13 @@ Box.prototype.addCloseButton = function () {
   var balloonRight = self.getLoc('balloon','x2') - margin - self.closeButtonWidth;
   var closeButton = document.getElementById('closeButton');
 
-
   if (!closeButton) {
     closeButton = new Image;
     closeButton.setAttribute('id','closeButton');
     closeButton.setAttribute('src',self.closeButton);
     closeButton.onclick = function() {
       Balloon.prototype.hideTooltip(1);
-      eval("login_blackout(false,'')");  // hack because we are using gbox to display login instructions on blacked out background
+      self.greyout(false);
     };
     self.setStyle(closeButton,'position','absolute');
     document.body.appendChild(closeButton);
