@@ -7,6 +7,7 @@ use base 'Bio::Graphics::Browser2::AuthorizedFeatureFile';
 use Bio::Graphics::Browser2::Shellwords;
 use Bio::Graphics::Browser2::Util 'modperl_request';
 use Bio::Graphics::Browser2::DataBase;
+use Bio::DB::SeqFeature::Store::Alias;
 use File::Basename 'dirname';
 use File::Path 'mkpath';
 use File::Spec;
@@ -977,7 +978,8 @@ sub open_database {
   $track  ||= 'general';
 
   my ($dbid,$adaptor,@argv) = $self->db_settings($track,$length);
-  my $db                    = Bio::Graphics::Browser2::DataBase->open_database($adaptor,@argv);
+  my $db                    = Bio::Graphics::Browser2::DataBase->open_database($adaptor,@argv) or return;
+  
   $self->fix_sqlite if $adaptor eq 'Bio::DB::SeqFeature::Store' && "@argv" =~ /SQLite/;  # work around broken bioperl
   
   # do a little extra stuff the first time we see a new database
@@ -994,6 +996,16 @@ sub open_database {
 
   }
 
+  # add extra semantic data if requested
+  if ($track ne 'general' && (my $metadata = $self->semantic_setting($track,'metadata',$length||0))) {
+      eval "require Bio::DB::SeqFeature::Store::Alias; 1;"
+	  unless Bio::DB::SeqFeature::Store::Alias->can('new');
+      my @feature_types = shellwords($self->semantic_setting($track,'feature',$length||0));
+      $db = Bio::DB::SeqFeature::Store::Alias->new(-store    => $db,
+						   -metadata => $metadata,
+						   -type     => $feature_types[0]);
+  }
+
   # remember mapping of this database to this track
   $self->{db2track}{$db}{$dbid}++;
 
@@ -1358,7 +1370,7 @@ sub use_inline_imagemap {
     my $inline = $self->semantic_fallback_setting($label=>'inline imagemaps',$length) 
 	       ||$self->semantic_fallback_setting($label=>'inline imagemap', $length);
     return $inline if defined $inline;
-    return 1 if not (Bio::Graphics::Browser2::Render->fcgi_request()
+    return 1 if not (Bio::Graphics::Browser2::Render->fcgi_running()
 		     ||
 		     $ENV{MOD_PERL_API_VERSION}
 	);
